import React, { useState, useEffect } from 'react';

function EditMaintenanceUser({ maintenance }) {
  const [status, setStatus] = useState(maintenance.status);
  const [reportExists, setReportExists] = useState(false);

  useEffect(() => {
    fetch(`/report/maintenance/${maintenance.id}`)
      .then(response => response.json())
      .then(data => setReportExists(data.length > 0))
      .catch(error => console.error('Error:', error));
  }, [maintenance.id]);

  const handleAccept = () => {
    fetch(`/maintenance/${maintenance.id}`, {
      method: 'PUT',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ status: 'in_progress' })
    })
      .then(response => response.json())
      .then(data => setStatus(data.status))
      .catch(error => console.error('Error:', error));
      window.location = "/user";
  };

  const handleFinish = () => {
    fetch(`/maintenance/${maintenance.id}`, {
      method: 'PUT',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ status: 'finished' })
    })
      .then(response => response.json())
      .then(data => {
        setStatus(data.status);

      })
      .catch(error => console.error('Error:', error));
      
    fetch(
      `/room/${maintenance.room_id}`,
      {
        method: "PUT",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ is_flagged: false })
      }
    )
      .then(roomResponse => roomResponse.json())
      .then(roomData => console.log(roomData))
      .catch(error => console.error('Error:', error));  
      
    window.location = "/user";
  };
  

  return (
    <div>
      <button
        type="button"
        className={`px-4 py-2 mb-2 text-white rounded ${status === 'pending' ? 'bg-[#32CD32] hover:bg-green-500' : 'bg-[#B0B0B0] cursor-not-allowed'}`}
        onClick={handleAccept}
        disabled={status !== 'pending'}
      >
        Accept
      </button>
      <button
        type="button"
        className={`px-4 py-2 mb-2 text-white rounded ${status === 'in_progress' ? 'bg-blue-500 hover:bg-blue-700' : 'bg-gray-500 cursor-not-allowed'}`}
        onClick={handleFinish}
        disabled={status !== 'in_progress' || !reportExists}
      >
        Finish
      </button>
    </div>
  );
};

export default EditMaintenanceUser;
